==> qucs-s-debug-24.4.0-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-24.4.0/builddir/qucsator_rf/src/converter/parse_spice.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_SPICE_PARSE_SPICE_HPP_INCLUDED
# define YY_SPICE_PARSE_SPICE_HPP_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int spice_debug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    TitleLine = 258,               /* TitleLine  */
    InvalidCharacter = 259,        /* InvalidCharacter  */
    End = 260,                     /* End  */
    Eol = 261,                     /* Eol  */
    Identifier = 262,              /* Identifier  */
    Digits = 263,                  /* Digits  */
    Floats = 264,                  /* Floats  */
    Nodes = 265,                   /* Nodes  */
    Options = 266,                 /* Options  */
    Function = 267,                /* Function  */
    SUBCKT_Action = 268,           /* SUBCKT_Action  */
    ENDS_Action = 269,             /* ENDS_Action  */
    AC_Action = 270,               /* AC_Action  */
    OP_Action = 271,               /* OP_Action  */
    I_Source = 272,                /* I_Source  */
    SAVE_Action = 273,             /* SAVE_Action  */
    RLC_Device = 274,              /* RLC_Device  */
    L_Device = 275,                /* L_Device  */
    K_Device = 276,                /* K_Device  */
    IV_Source = 277,               /* IV_Source  */
    GE_Source = 278,               /* GE_Source  */
    FH_Source = 279,               /* FH_Source  */
    V_Source = 280,                /* V_Source  */
    Diode_Device = 281,            /* Diode_Device  */
    Bipolar_Device = 282,          /* Bipolar_Device  */
    JFET_Device = 283,             /* JFET_Device  */
    MOSFET_Device = 284,           /* MOSFET_Device  */
    MESFET_Device = 285,           /* MESFET_Device  */
    MODEL_Action = 286,            /* MODEL_Action  */
    MODEL_Spec = 287,              /* MODEL_Spec  */
    TRAN_Action = 288,             /* TRAN_Action  */
    PLOT_Action = 289,             /* PLOT_Action  */
    VoltFunc = 290,                /* VoltFunc  */
    CurrFunc = 291,                /* CurrFunc  */
    DC_Action = 292,               /* DC_Action  */
    PRINT_Action = 293,            /* PRINT_Action  */
    OPTIONS_Action = 294,          /* OPTIONS_Action  */
    WIDTH_Action = 295,            /* WIDTH_Action  */
    NOISE_Action = 296,            /* NOISE_Action  */
    PZ_Action = 297,               /* PZ_Action  */
    CurVol = 298,                  /* CurVol  */
    PoleZero = 299,                /* PoleZero  */
    ALL_Special = 300,             /* ALL_Special  */
    X_Device = 301,                /* X_Device  */
    O_Device = 302,                /* O_Device  */
    ModelProps = 303,              /* ModelProps  */
    OFF_Special = 304,             /* OFF_Special  */
    IC_Special = 305,              /* IC_Special  */
    SIM_Type = 306,                /* SIM_Type  */
    TEMP_Special = 307,            /* TEMP_Special  */
    MOS_Special = 308,             /* MOS_Special  */
    B_Source = 309,                /* B_Source  */
    DISTO_Action = 310,            /* DISTO_Action  */
    INCLUDE_Action = 311,          /* INCLUDE_Action  */
    File = 312,                    /* File  */
    BranchFunc = 313,              /* BranchFunc  */
    NODESET_Action = 314,          /* NODESET_Action  */
    T_Device = 315,                /* T_Device  */
    U_Device = 316,                /* U_Device  */
    S_Device = 317,                /* S_Device  */
    W_Device = 318,                /* W_Device  */
    ON_Special = 319,              /* ON_Special  */
    TF_Action = 320,               /* TF_Action  */
    SENS_Action = 321,             /* SENS_Action  */
    FOUR_Action = 322,             /* FOUR_Action  */
    OpFunc = 323,                  /* OpFunc  */
    Behave = 324,                  /* Behave  */
    TC_Special = 325,              /* TC_Special  */
    TEMP_Action = 326              /* TEMP_Action  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union YYSTYPE
{
#line 146 "/build/qucs-s/src/qucs-s-24.4.0/qucsator_rf/src/converter/parse_spice.ypp"

  char * ident;
  char * str;
  double d;
  struct definition_t * definition;
  struct definition_t * subcircuit;
  struct value_t * value;

#line 144 "parse_spice.hpp"

};
typedef union YYSTYPE YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE spice_lval;


int spice_parse (void);


#endif /* !YY_SPICE_PARSE_SPICE_HPP_INCLUDED  */

==> qucs-s-debug-25.1.1-1-x86_64.pkg.tar.zst: usr/src/debug/qucs-s/qucs-s-25.1.1/builddir/qucsator_rf/src/converter/parse_spice.hpp <==
/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_SPICE_PARSE_SPICE_HPP_INCLUDED
# define YY_SPICE_PARSE_SPICE_HPP_INCLUDED
/* Debug traces.  */
#ifndef SPICE_DEBUG
# if defined YYDEBUG
#if YYDEBUG
#   define SPICE_DEBUG 1
#  else
#   define SPICE_DEBUG 0
#  endif
# else /* ! defined YYDEBUG */
#  define SPICE_DEBUG 0
# endif /* ! defined YYDEBUG */
#endif  /* ! defined SPICE_DEBUG */
#if SPICE_DEBUG
extern int spice_debug;
#endif

/* Token kinds.  */
#ifndef SPICE_TOKENTYPE
# define SPICE_TOKENTYPE
  enum spice_tokentype
  {
    SPICE_EMPTY = -2,
    SPICE_EOF = 0,                 /* "end of file"  */
    SPICE_error = 256,             /* error  */
    SPICE_UNDEF = 257,             /* "invalid token"  */
    TitleLine = 258,               /* TitleLine  */
    InvalidCharacter = 259,        /* InvalidCharacter  */
    End = 260,                     /* End  */
    Eol = 261,                     /* Eol  */
    Identifier = 262,              /* Identifier  */
    Digits = 263,                  /* Digits  */
    Floats = 264,                  /* Floats  */
    Nodes = 265,                   /* Nodes  */
    Options = 266,                 /* Options  */
    Function = 267,                /* Function  */
    SUBCKT_Action = 268,           /* SUBCKT_Action  */
    ENDS_Action = 269,             /* ENDS_Action  */
    AC_Action = 270,               /* AC_Action  */
    OP_Action = 271,               /* OP_Action  */
    I_Source = 272,                /* I_Source  */
    SAVE_Action = 273,             /* SAVE_Action  */
    RLC_Device = 274,              /* RLC_Device  */
    L_Device = 275,                /* L_Device  */
    K_Device = 276,                /* K_Device  */
    IV_Source = 277,               /* IV_Source  */
    GE_Source = 278,               /* GE_Source  */
    FH_Source = 279,               /* FH_Source  */
    V_Source = 280,                /* V_Source  */
    Diode_Device = 281,            /* Diode_Device  */
    Bipolar_Device = 282,          /* Bipolar_Device  */
    JFET_Device = 283,             /* JFET_Device  */
    MOSFET_Device = 284,           /* MOSFET_Device  */
    MESFET_Device = 285,           /* MESFET_Device  */
    MODEL_Action = 286,            /* MODEL_Action  */
    MODEL_Spec = 287,              /* MODEL_Spec  */
    TRAN_Action = 288,             /* TRAN_Action  */
    PLOT_Action = 289,             /* PLOT_Action  */
    VoltFunc = 290,                /* VoltFunc  */
    CurrFunc = 291,                /* CurrFunc  */
    DC_Action = 292,               /* DC_Action  */
    PRINT_Action = 293,            /* PRINT_Action  */
    OPTIONS_Action = 294,          /* OPTIONS_Action  */
    WIDTH_Action = 295,            /* WIDTH_Action  */
    NOISE_Action = 296,            /* NOISE_Action  */
    PZ_Action = 297,               /* PZ_Action  */
    CurVol = 298,                  /* CurVol  */
    PoleZero = 299,                /* PoleZero  */
    ALL_Special = 300,             /* ALL_Special  */
    X_Device = 301,                /* X_Device  */
    O_Device = 302,                /* O_Device  */
    ModelProps = 303,              /* ModelProps  */
    OFF_Special = 304,             /* OFF_Special  */
    IC_Special = 305,              /* IC_Special  */
    SIM_Type = 306,                /* SIM_Type  */
    TEMP_Special = 307,            /* TEMP_Special  */
    MOS_Special = 308,             /* MOS_Special  */
    B_Source = 309,                /* B_Source  */
    DISTO_Action = 310,            /* DISTO_Action  */
    INCLUDE_Action = 311,          /* INCLUDE_Action  */
    File = 312,                    /* File  */
    BranchFunc = 313,              /* BranchFunc  */
    NODESET_Action = 314,          /* NODESET_Action  */
    T_Device = 315,                /* T_Device  */
    U_Device = 316,                /* U_Device  */
    S_Device = 317,                /* S_Device  */
    W_Device = 318,                /* W_Device  */
    ON_Special = 319,              /* ON_Special  */
    TF_Action = 320,               /* TF_Action  */
    SENS_Action = 321,             /* SENS_Action  */
    FOUR_Action = 322,             /* FOUR_Action  */
    OpFunc = 323,                  /* OpFunc  */
    Behave = 324,                  /* Behave  */
    TC_Special = 325,              /* TC_Special  */
    TEMP_Action = 326              /* TEMP_Action  */
  };
  typedef enum spice_tokentype spice_token_kind_t;
#endif

/* Value type.  */
#if ! defined SPICE_STYPE && ! defined SPICE_STYPE_IS_DECLARED
union SPICE_STYPE
{
#line 146 "/build/qucs-s/src/qucs-s-25.1.1/qucsator_rf/src/converter/parse_spice.ypp"

  char * ident;
  char * str;
  double d;
  struct definition_t * definition;
  struct definition_t * subcircuit;
  struct value_t * value;

#line 152 "parse_spice.hpp"

};
typedef union SPICE_STYPE SPICE_STYPE;
# define SPICE_STYPE_IS_TRIVIAL 1
# define SPICE_STYPE_IS_DECLARED 1
#endif


extern SPICE_STYPE spice_lval;


int spice_parse (void);


#endif /* !YY_SPICE_PARSE_SPICE_HPP_INCLUDED  */
